Qu’est-ce que l’OiRA? | OiRA

Thèmes

# Qu’est-ce que l’OiRA?

## Vous découvrez l’OiRA?

Voici une brève introduction à l’évaluation des risques et aux moyens offerts par l’OiRA pour vous aider à la gérer.

## Qu’est-ce qu’une évaluation des risques?

L’évaluation des risques est la base d’une gestion réussie de la sécurité et de la santé, et la clé pour réduire les accidents du travail et les maladies professionnelles. Si elle est mise en œuvre de manière adéquate, elle peut améliorer la santé et la sécurité au travail - et les performances des entreprises en général.

En Europe, la protection de la sécurité et de la santé des travailleurs passe par l’évaluation et la gestion des risques sur le lieu de travail. Les employeurs ont l’obligation légale d’assurer la sécurité et la santé des travailleurs dans tous les aspects liés au travail et de procéder à une évaluation des risques. Chaque entreprise doit donc en réaliser une et élaborer un plan d’action. Pour évaluer efficacement les risques sur le lieu de travail, toutes les personnes concernées doivent avoir une bonne compréhension:

- du contexte juridique et des concepts;
- du processus suivi pour évaluer les risques;
- du rôle joué par les principaux acteurs impliqués dans le processus.

Les travailleurs et/ou leurs représentants ont le droit d’être consultés sur les modalités de réalisation de l’évaluation des risques et à y participer.

Vous pouvez trouver plus d’informations sur l’évaluation des risques et la participation des travailleurs et/ou de leurs représentants au processus d’évaluation des risques sur le site web du projet OiRA.

## Qu’est-ce que l’OiRA?

L’OiRA - Outil interactif d’évaluation des risques en ligne - est une application basée sur le web qui vous permet d’effectuer une évaluation des risques pour la santé et la sécurité de votre lieu de travail.

## À qui s’adresse l’OiRA?

L’OiRA peut être utilisé par quiconque désireux d’évaluer les risques liés à la sécurité et à la santé qui pourraient exister sur son lieu de travail.

Toutefois, l’OiRA est conçu pour être particulièrement utile aux petites entreprises. Il a été développé spécifiquement pour les aider à évaluer les risques au travail et à produire une évaluation documentée des risques, y compris un plan d’action adapté aux besoins de l’établissement.

## Qu’est-ce que je dois faire?

Le processus d’évaluation des risques de l’OiRAcomprend plusieurs étapes:

- Préparation: certains outils comportent des questions sur le profil qui vous aident à adapter l’outil aux spécificités de votre organisation. Lorsque vous répondrez aux questions sur le profil, l’outil s’adaptera à votre situation et affichera les modules pertinents.

- Participation: toute évaluation des risques devrait être réalisée avec la participation active des travailleurs. L’outil vous permet d’imprimer le texte complet de l’évaluation des risques, ou seulement des parties de celle-ci, afin d’informer les travailleurs et de recueillir leurs commentaires.

- Identification des risques: L’OiRA présentera une série de risques ou de problèmes potentiels pour la sécurité et la santé qui pourraient exister sur votre lieu de travail. En répondant aux questions/énoncés par oui ou par non, vous indiquez si ces risques ou problèmes sont présents. Vous pouvez également laisser une question en attente et y répondre ultérieurement.

- Évaluation: certains outils vous demandent de classer par ordre de priorité les risques que vous avez identifiés. Différentes méthodes existent à cet effet, en fonction des choix faits par nos partenaires nationaux/développeurs d’outils OiRA et de leur approche respective. Certains outils hiérarchisent les risques automatiquement en arrière-plan et vous pouvez ignorer ce classement.

- Plan d’action: pour chaque risque identifié, l’outil vous demande de déterminer une ou plusieurs mesures visant à éliminer ou à réduire le risque. La plupart des outils vous suggèrent quelques mesures. Vous pouvez aussi toujours choisir de saisir vos propres mesures.

- Rapport: vous êtes légalement tenu de documenter votre évaluation des risques. Dans la section «Rapport», vous trouverez différents rapports qui vous aideront à consigner votre évaluation des risques et à assurer le suivi des actions/mesures que vous avez décidé de mettre en œuvre pour éliminer ou atténuer les risques identifiés.

## Combien de temps cela prendra-t-il?

Il est impossible de dire combien de temps durera une évaluation de manière générale car les outils diffèrent selon le secteur d’activité et le pays.

Vous pouvez y consacrer le temps dont vous disposez, puis quand cela vous convient, reprendre là où vous vous étiez arrêté.

## Pourquoi dois-je m’enregistrer?

Lorsque vous commencerez votre première évaluation des risques, il vous sera demandé de créer un compte OiRA. Il s’agit d’une procédure simple et rapide.

L’enregistrement vous permet de vous connecter facilement à tout moment pour poursuivre les évaluations précédentes ou en commencer de nouvelles.

Si vous êtes un utilisateur enregistré, vous pouvez également obtenir à tout moment une version imprimée, précise et actualisée de l’évaluation des risques.

## Dois-je me préparer?

Vous n’avez besoin d’aucune préparation particulière pour commencer à utiliser l’outil. Vous devriez cependant prendre le temps de réfléchir au choix de la personne qui va effectuer l’évaluation des risques et à la manière dont les travailleurs seront associés au processus.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More